#Change log versions
## 1.4
- versioning utilities : retrieves version number labelled as ##<version> in a changelog.md and puts it in `_version.py`. The file must be in the same folder as the `__init__.py`
- added jupy_utils
## 1.2
- initial versioning
## 1.1
- minor changes to display standards and physicsConstants
- added gears and struct_meca
## 1.0.13
- added pytest_util
- dsp.stddisp bug fix inset
- displayStandards tick_direction tdir
- added axPos full 'F' key
